@@ -15,8 +15,7 @@ niter = 10
 
 random.fit = HLSM(X = ps.edge.vars.mat,Y = ps.advice.mat,
 	initialVals = initialVals,priors = priors,
-	tune = tune,tuneIn = FALSE,dd = 2,niter = niter,
-	intervention = 0)
+	tune = tune,tuneIn = FALSE,dd = 2,niter = niter)
 
 
 summary(random.fit)
@@ -24,12 +23,8 @@ names(random.fit)
 
 fixed.fit = HLSMfixedEF(X = ps.edge.vars.mat,Y = ps.advice.mat,
 	initialVals = initialVals,priors = priors,
-	tune = tune,tuneIn = FALSE,dd = 2,niter = niter,
-	intervention = 0)
+	tune = tune,tuneIn = FALSE,dd = 2,niter = niter)
+
 summary(fixed.fit)
 names(fixed.fit)
 
-
-
-
-
